@@ -220,6 +220,7 @@ class BamParser:
                 cov_cuts = (np.max([0., cov_mean-cov_std]), cov_mean+cov_std) 
                 tcov = [c for c in cov if c >= cov_cuts[0] and c <= cov_cuts[1]]
                 coverages[reference] = np.mean(tcov)
+                #print "##", np.std(tcov)
         if(doCoverage):
             return (all_links, coverages, dict(zip(references,ref_lengths)))
         else:
@@ -726,9 +727,9 @@ class BamParser:
                 bam_file = pysam.Samfile(bf, 'rb')
                 if verbose:
                     print "Determining OT for BAM '%s'" % (getBamDescriptor(bf))
-                (OT,ins,std) = self.classifyBamType(bam_file)
-                if verbose:
-                    print "Orientation: %s Insert: %d, Stdev: %d" % (self.OT2Str(OT), ins, std) 
+                    (OT,ins,std) = self.classifyBamType(bam_file, all=True)
+                else:
+                    (OT,ins,std) = self.classifyBamType(bam_file)
                 bam_types[bam_count] = (OT,ins,std)                
                 bam_count += 1
                 bam_file.close()
@@ -737,7 +738,7 @@ class BamParser:
                 raise
         return bam_types
     
-    def classifyBamType(self, bamFile, numPaired=10000):
+    def classifyBamType(self, bamFile, numPaired=10000, all=True):
         """Parse a bam file (handle) to determine the read orientation type
         
         numPaired refers to the number of mapped pairs we need before
@@ -766,6 +767,7 @@ class BamParser:
                         else:
                             # otherwise it comes after
                             (OT,ins) = self.determineOTSameRef(seen_reads[query], alignedRead)
+
                         OTs[OT].append(ins)
                         num_stored += 1
                 else:
@@ -773,6 +775,12 @@ class BamParser:
         
         # now determine the stats for this bamfile
         # we'd like the vast majority of the OT's to agree
+        
+        if all:
+            for OT in OTs:
+                if len(OTUs[OT]) != 0:
+                    print "Orientation: %s Insert mean: %d Stdev: %d Num: %d" % (self.OT2Str(OT), int(np.mean(OTs[OT])), int(np.std(OTs[OT])), len(OTs[OT]))
+        
         cutoff = int(num_stored * 0.9)
         for OT in OTs:
             if len(OTs[OT]) > cutoff:
@@ -836,7 +844,7 @@ def makeSurePathExists(path):
 ###############################################################################
 
 class ReadLoader:
-    """AUX: Call back for counting aligned reads
+    """AUX: Call back for getting aligned reads
     
     Used in conjunction with pysam.fetch 
     """
